import json
import time

from tqdm import tqdm

from gfypy.client.abstract_client import AbstractGfypy
from gfypy.const import GFYCAT_URL, FILEDROP_ENDPOINT
from gfypy.exceptions import GfypyAuthException, GfypyApiException
from gfypy.gfy import Gfy
from gfypy.http import SyncHttpClient
from gfypy.route import Route, CustomRoute


class Gfypy(AbstractGfypy):
    def __init__(self, client_id, client_secret, auth_file_path):
        super().__init__(client_id, client_secret, auth_file_path)
        self._http = SyncHttpClient(client_id, client_secret)

    def authenticate(self):
        if not self._auth_file_path.is_file():
            print(f'Credentials file "{self._auth_file_path}" does not exist. Creating it now.')
            with open(self._auth_file_path, 'w') as auth_file:
                auth_file.write(json.dumps(self._http.creds))

        with open(self._auth_file_path, 'r') as auth_file:
            self._http.creds = json.loads(auth_file.read())

            try:
                self._http.refresh_oauth_token(refresh=False)
            except GfypyAuthException as e:
                if e.code == 'InvalidRefreshToken':
                    self._initial_auth()
                    self._auth_to_disk()
                else:
                    raise

    def _initial_auth(self):
        self._http.get_oauth_token(self._get_oauth_code())

    def upload_from_file(self, filename, title='', tags=[], keep_audio=True, check_duplicate=False, check_upload=True):
        key = self._get_key(title, tags, keep_audio, check_duplicate)
        payload = {
            'key': key
        }
        files = {
            'file': (key, open(filename, 'rb').read())
        }

        self._http.request(CustomRoute('POST', FILEDROP_ENDPOINT), data=payload, files=files, no_auth=True)

        if check_upload:
            status = self._check_upload_status(key)

            progress = tqdm(total=self.MAX_CHECKS)
            num_checks = 0
            while status['task'] != 'complete':
                if num_checks > self.MAX_CHECKS:
                    # the gfycat was likely uploaded correctly, but gfycat is not sending 'task': 'complete'
                    break
                status = self._check_upload_status(key)
                progress.update(1)
                num_checks += 1
                time.sleep(3)

            progress.close()

            try:
                gfy = self.get_gfycat(key)

                print(f'\n{filename} has been uploaded as {GFYCAT_URL}/{key}.')
                return gfy
            except GfypyApiException:
                print(f'\n{filename} has probably been uploaded as {GFYCAT_URL}/{key}, but the check was unsuccessful.')
                return None
        else:
            print(f'\n{filename} has been uploaded as {GFYCAT_URL}/{key}; checks have been skipped.')

    def get_followers(self, fetch_userdata=False):
        resp = self._http.request(Route('GET', '/me/followers'))

        if not fetch_userdata:
            return resp['followers']
        else:
            users = []
            for follower in resp['followers']:
                user = self.get_user(follower['follower_id'])
                user['follow_date'] = follower['follow_date']
                users.append(user)

            return users

    def get_user_feed(self, user_id=None, limit=100, sort_by=None, desc=True, filter_predicate=None):
        if limit % 100 != 0 and limit >= 0:
            print(f'Limit needs to be divisible by 100. Rounding up.')

        gfycats = []
        i = 0
        cursor = ''

        if user_id is None:
            route = Route('GET', '/me/gfycats')
        else:
            route = Route('GET', '/users/{id}/gfycats', id=user_id)

        progress = tqdm(total=limit)

        while i < limit or limit < 0:
            resp = self._http.request(route, params={'count': 100, 'cursor': cursor})

            cursor = resp['cursor']
            new_gfys = Gfy.from_dict_list(self, resp['gfycats'])
            gfycats.extend(new_gfys)
            progress.update(len(new_gfys))

            if not cursor:
                print('Got no new entries from Gfycat. Stopping here.')
                break

            i = len(gfycats)

        progress.close()

        if filter_predicate:
            gfycats = [g for g in gfycats if filter_predicate(g)]

        if sort_by:
            gfycats = sorted(gfycats, key=lambda gfy: getattr(gfy, sort_by), reverse=desc)

        return gfycats



import json

import requests

from gfypy.const import REDIRECT_URI
from gfypy.exceptions import GfypyAuthException, GfypyApiException
from gfypy.http.abstract_http import AbstractHttpClient
from gfypy.route import Route


class BearerAuth(requests.auth.AuthBase):
    def __init__(self, token):
        self.token = token

    def __call__(self, r):
        r.headers["authorization"] = "Bearer " + self.token
        return r


class SyncHttpClient(AbstractHttpClient):
    def __init__(self, client_id, client_secret):
        self._client_id = client_id
        self._client_secret = client_secret
        self._session = requests.Session()
        self._auth = None
        self.creds = {
            'access_token': None,
            'expires_in': None,
            'refresh_token': None,
            'refresh_token_expires_in': None,
            'resource_owner': None
        }

    def request(self, route, **kwargs):
        no_auth = kwargs.pop('no_auth', False)
        refresh = kwargs.pop('refresh', True)

        if self._auth is not None and not no_auth:
            resp = self._session.request(route.method, route.url, **kwargs, auth=self._auth)
        else:
            resp = self._session.request(route.method, route.url, **kwargs)

        content_type = resp.headers.get('content-type')

        if content_type == 'application/json':
            content = resp.json()
        else:
            content = resp.text

        if 200 <= resp.status_code < 300:
            return content
        elif resp.status_code in [401, 403]:
            if refresh:
                # try to refresh the oauth token in case it's become invalid
                self.refresh_oauth_token()

                return self.request(route, **kwargs, refresh=False)
            else:
                if 'message' in content:
                    raise GfypyAuthException(content['message'], resp.status_code, None)
                else:
                    raise GfypyAuthException(content['errorMessage']['description'], resp.status_code,
                                             content['errorMessage']['code'])
        else:
            raise GfypyApiException(content['errorMessage'] if 'message' in content else content, resp.status_code)

    def get_oauth_token(self, code):
        payload = {
            'code': code,
            'client_id': self._client_id,
            'client_secret': self._client_secret,
            'grant_type': 'authorization_code',
            'redirect_uri': REDIRECT_URI
        }

        resp = self.request(Route('POST', '/oauth/token'), data=json.dumps(payload),
                            headers={'content-type': 'application/json'})

        self.creds = resp
        self.auth = resp['access_token']

    def refresh_oauth_token(self, **kwargs):
        payload = {
            'refresh_token': self.creds['refresh_token'],
            'client_id': self._client_id,
            'client_secret': self._client_secret,
            'grant_type': 'refresh',
        }

        resp = self.request(Route('POST', '/oauth/token'), data=json.dumps(payload),
                            headers={'content-type': 'application/json'}, **kwargs)

        self.creds = resp
        self.auth = resp['access_token']

    @property
    def auth(self):
        return self._auth

    @auth.setter
    def auth(self, token):
        self._auth = BearerAuth(token)



import json

import aiohttp

from gfypy.const import REDIRECT_URI
from gfypy.exceptions import GfypyAuthException, GfypyApiException
from gfypy.http.abstract_http import AbstractHttpClient
from gfypy.route import Route


class BearerAuth(aiohttp.BasicAuth):
    def __init__(self, token):
        self.token = token

    def encode(self):
        return "Bearer " + self.token


class AsyncHttpClient(AbstractHttpClient):
    def __init__(self, client_id, client_secret):
        self._client_id = client_id
        self._client_secret = client_secret
        self._session = aiohttp.ClientSession()
        self._auth = None
        self.creds = {
            'access_token': None,
            'expires_in': None,
            'refresh_token': None,
            'refresh_token_expires_in': None,
            'resource_owner': None
        }

    async def close(self):
        await self._session.close()

    async def request(self, route, **kwargs):
        no_auth = kwargs.pop('no_auth', False)
        refresh = kwargs.pop('refresh', True)

        async with self._session.request(route.method, route.url, **kwargs,
                                         auth=self._auth if not no_auth else None) as resp:
            content_type = resp.headers.get('content-type')
            if content_type == 'application/json':
                content = await resp.json()
            else:
                content = await resp.text()

            if 200 <= resp.status < 300:
                return content
            elif resp.status in [401, 403]:
                if refresh:
                    # try to refresh the oauth token in case it's become invalid
                    await self.refresh_oauth_token()

                    return await self.request(route, **kwargs, refresh=False)
                else:
                    if 'message' in content:
                        raise GfypyAuthException(content['message'], resp.status, None)
                    else:
                        raise GfypyAuthException(content['errorMessage']['description'], resp.status,
                                                 content['errorMessage']['code'])
            else:
                raise GfypyApiException(content['errorMessage'] if 'message' in content else content, resp.status)

    async def get_oauth_token(self, code):
        payload = {
            'code': code,
            'client_id': self._client_id,
            'client_secret': self._client_secret,
            'grant_type': 'authorization_code',
            'redirect_uri': REDIRECT_URI
        }

        resp = await self.request(Route('POST', '/oauth/token'), data=json.dumps(payload),
                                  headers={'content-type': 'application/json'})

        self.creds = resp
        self.auth = resp['access_token']

    async def refresh_oauth_token(self, **kwargs):
        payload = {
            'refresh_token': self.creds['refresh_token'],
            'client_id': self._client_id,
            'client_secret': self._client_secret,
            'grant_type': 'refresh',
        }

        resp = await self.request(Route('POST', '/oauth/token'), data=json.dumps(payload),
                                  headers={'content-type': 'application/json'}, **kwargs)

        self.creds = resp
        self.auth = resp['access_token']

    @property
    def auth(self):
        return self._auth

    @auth.setter
    def auth(self, token):
        self._auth = BearerAuth(token)



import asyncio
import json

from aiohttp import FormData

from gfypy.client.abstract_client import AbstractGfypy
from gfypy.const import FILEDROP_ENDPOINT, GFYCAT_URL
from gfypy.exceptions import GfypyAuthException, GfypyApiException
from gfypy.gfy import Gfy
from gfypy.http import AsyncHttpClient
from gfypy.route import CustomRoute
from gfypy.route import Route


class AsyncGfypy(AbstractGfypy):
    def __init__(self, client_id, client_secret, auth_file_path):
        super().__init__(client_id, client_secret, auth_file_path)
        self._http = AsyncHttpClient(client_id, client_secret)

    async def authenticate(self):
        if not self._auth_file_path.is_file():
            print(f'Credentials file "{self._auth_file_path}" does not exist. Creating it now.')
            with open(self._auth_file_path, 'w') as auth_file:
                auth_file.write(json.dumps(self._http.creds))

        with open(self._auth_file_path, 'r') as auth_file:
            self._http.creds = json.loads(auth_file.read())

            try:
                await self._http.refresh_oauth_token(refresh=False)
            except GfypyAuthException as e:
                if e.code == 'InvalidRefreshToken':
                    await self._initial_auth()
                    self._auth_to_disk()
                else:
                    raise

    async def close(self):
        await self._http.close()

    async def _initial_auth(self):
        await self._http.get_oauth_token(self._get_oauth_code())

    async def upload_from_file(self, filename, title='', tags=[], keep_audio=True, check_duplicate=False, check_upload=True):
        key = await self._get_key(title, tags, keep_audio, check_duplicate)

        data = FormData()
        data.add_field('key', key)
        data.add_field('file', open(filename, 'rb'), filename=filename)

        await self._http.request(CustomRoute('POST', FILEDROP_ENDPOINT), data=data, no_auth=True)

        if check_upload:
            status = await self._check_upload_status(key)

            num_checks = 0
            while status['task'] != 'complete':
                if num_checks > self.MAX_CHECKS:
                    # the gfycat was likely uploaded correctly, but gfycat is not sending 'task': 'complete'
                    break
                status = await self._check_upload_status(key)
                num_checks += 1
                await asyncio.sleep(3)

            try:
                gfy = await self.get_gfycat(key)

                print(f'\n{filename} has been uploaded as {GFYCAT_URL}/{key}.')
                return gfy
            except GfypyApiException:
                print(f'\n{filename} has probably been uploaded as {GFYCAT_URL}/{key}, but the check was unsuccessful.')
                return None
        else:
            print(f'\n{filename} has been uploaded as {GFYCAT_URL}/{key}; checks have been skipped.')

    async def user_feed_generator(self, user_id=None, per_request=100):
        if not 20 <= per_request <= 100:
            print(f'Number per request needs to be between 20 and 100.')
            return

        i = 0
        cursor = ''

        if user_id is None:
            route = Route('GET', '/me/gfycats')
        else:
            route = Route('GET', '/users/{id}/gfycats', id=user_id)

        while True:
            resp = await self._http.request(route, params={'count': per_request, 'cursor': cursor})

            cursor = resp['cursor']
            new_gfys = Gfy.from_dict_list(self, resp['gfycats'])
            for new_gfy in new_gfys:
                yield new_gfy

            if not cursor:
                print('Got no new entries from Gfycat. Stopping here.')
                break

    async def get_user_feed(self, user_id=None, limit=100, sort_by=None, desc=True, filter_predicate=None):
        if limit % 100 != 0 and limit >= 0:
            print(f'Limit needs to be divisible by 100. Rounding up.')

        gfycats = []

        async for gfy in self.user_feed_generator(user_id=user_id, per_request=100):
            gfycats.append(gfy)

            if len(gfycats) >= limit >= 0:
                break

        if filter_predicate:
            gfycats = [g for g in gfycats if filter_predicate(g)]

        if sort_by:
            gfycats = sorted(gfycats, key=lambda gfy: getattr(gfy, sort_by), reverse=desc)

        return gfycats



import json
from datetime import datetime

from .route import Route

from dataclasses import dataclass
from typing import List, Any, Set, Optional


@dataclass
class ContentUrl:
    url: str
    size: int
    height: int
    width: int

    def __init__(self, **kwargs):
        self.url = kwargs.pop('url', None)
        self.size = kwargs.pop('size', None)
        self.height = kwargs.pop('height', None)
        self.width = kwargs.pop('width', None)


@dataclass
class UserData:
    name: str
    profile_image_url: str
    url: str
    username: str
    followers: int
    subscription: int
    following: int
    profile_url: str
    views: int
    verified: bool

    def __init__(self, **kwargs):
        self.name = kwargs.pop('name', None)
        self.profile_image_url = kwargs.pop('profileImageUrl', None)
        self.url = kwargs.pop('url', None)
        self.username = kwargs.pop('username', None)
        self.followers = kwargs.pop('followers', None)
        self.subscription = kwargs.pop('subscription', None)
        self.following = kwargs.pop('following', None)
        self.profile_url = kwargs.pop('profileUrl', None)
        self.views = kwargs.pop('views', None)
        self.verified = kwargs.pop('verified', None)


@dataclass
class ContentUrls:
    max2_mb_gif: ContentUrl
    webp: ContentUrl
    max1_mb_gif: ContentUrl
    _100_px_gif: ContentUrl
    mobile_poster: ContentUrl
    mp4: ContentUrl
    webm: ContentUrl
    max5_mb_gif: ContentUrl
    large_gif: ContentUrl
    mobile: ContentUrl

    def __init__(self, **kwargs):
        self.max2_mb_gif = ContentUrl(**kwargs.pop('max2mbGif')) if 'max2mbGif' in kwargs else None
        self.webp = ContentUrl(**kwargs.pop('webp')) if 'webp' in kwargs else None
        self.max1_mb_gif = ContentUrl(**kwargs.pop('max1mbGif')) if 'max1mbGif' in kwargs else None
        self._100_px_gif = ContentUrl(**kwargs.pop('100pxGif')) if '100pxGif' in kwargs else None
        self.mobile_poster = ContentUrl(**kwargs.pop('mobilePoster')) if 'mobilePoster' in kwargs else None
        self.mp4 = ContentUrl(**kwargs.pop('mp4')) if 'mp4' in kwargs else None
        self.webm = ContentUrl(**kwargs.pop('webm')) if 'webm' in kwargs else None
        self.max5_mb_gif = ContentUrl(**kwargs.pop('max5mbGif')) if 'max5mbGif' in kwargs else None
        self.large_gif = ContentUrl(**kwargs.pop('largeGif')) if 'largeGif' in kwargs else None
        self.mobile = ContentUrl(**kwargs.pop('mobile')) if 'mobile' in kwargs else None


@dataclass
class Gfy(dict):
    tags: Set[str]
    language_categories: List[Any]
    domain_whitelist: List[Any]
    geo_whitelist: List[Any]
    published: int
    nsfw: str
    gatekeeper: int
    mp4_url: str
    gif_url: str
    webm_url: str
    webp_url: str
    mobile_url: str
    mobile_poster_url: str
    extra_lemmas: str
    thumb100_poster_url: str
    mini_url: str
    gif100_px: str
    mini_poster_url: str
    max5_mb_gif: str
    title: str
    max2_mb_gif: str
    max1_mb_gif: str
    poster_url: str
    language_text: str
    views: int
    user_name: str
    description: str
    sitename: str
    has_transparency: bool
    has_audio: bool
    likes: int
    dislikes: int
    gfy_number: int
    user_display_name: str
    user_profile_image_url: str
    gfy_id: str
    gfy_name: str
    avg_color: str
    width: int
    height: int
    frame_rate: float
    num_frames: int
    mp4_size: int
    webm_size: int
    create_date: datetime
    source: int
    content_urls: Optional[ContentUrls]
    user_data: Optional[UserData]

    def __init__(self, http, **kwargs):
        super().__init__(kwargs)
        self._http = http
        self._source = kwargs

        self.content_urls = ContentUrls(**kwargs.pop('content_urls', {}))
        self.user_data = UserData(**kwargs.pop('userData', {}))

        # explicit cast to int required because the API sometimes returns a str
        self.likes = int(kwargs.pop('likes', 0))
        self.dislikes = int(kwargs.pop('dislikes', 0))
        self.gfy_number = int(kwargs.pop('gfyNumber', 0))

        self.title = kwargs.pop('title', None)
        self.tags = set(kwargs.pop('tags', None))
        self.language_categories = kwargs.pop('languageCategories', [])
        self.domain_whitelist = kwargs.pop('domainWhitelist', [])
        self.geo_whitelist = kwargs.pop('geoWhitelist', [])
        self.published = kwargs.pop('published', None)
        self.nsfw = kwargs.pop('nsfw', None)
        self.gatekeeper = kwargs.pop('gatekeeper', None)
        self.mp4_url = kwargs.pop('mp4Url', None)
        self.gif_url = kwargs.pop('gifUrl', None)
        self.webm_url = kwargs.pop('webmUrl', None)
        self.webp_url = kwargs.pop('webpUrl', None)
        self.mobile_url = kwargs.pop('mobileUrl', None)
        self.mobile_poster_url = kwargs.pop('mobilePosterUrl', None)
        self.extra_lemmas = kwargs.pop('extraLemmas', None)
        self.thumb100_poster_url = kwargs.pop('thumb100PosterUrl', None)
        self.mini_url = kwargs.pop('miniUrl', None)
        self.gif100_px = kwargs.pop('gif100px', None)
        self.mini_poster_url = kwargs.pop('miniPosterUrl', None)
        self.max5_mb_gif = kwargs.pop('max5mbGif', None)
        self.max2_mb_gif = kwargs.pop('max2mbGif', None)
        self.max1_mb_gif = kwargs.pop('max1mbGif', None)
        self.poster_url = kwargs.pop('posterUrl', None)
        self.language_text = kwargs.pop('languageText', None)
        self.views = kwargs.pop('views', None)
        self.user_name = kwargs.pop('userName', None)
        self.description = kwargs.pop('description', None)
        self.sitename = kwargs.pop('sitename', None)
        self.has_transparency = kwargs.pop('hasTransparency', None)
        self.has_audio = kwargs.pop('hasAudio', None)
        self.gfy_id = kwargs.pop('gfyId', None)
        self.gfy_name = kwargs.pop('gfyName', None)
        self.width = kwargs.pop('width', None)
        self.height = kwargs.pop('height', None)
        self.frame_rate = kwargs.pop('frameRate', None)
        self.num_frames = kwargs.pop('numFrames', None)
        self.mp4_size = kwargs.pop('mp4Size', None)
        self.webm_size = kwargs.pop('webmSize', None)
        self.create_date = datetime.fromtimestamp(kwargs.pop('createDate', None))
        self.source = kwargs.pop('source', None)
        self.gfy_slug = kwargs.pop('gfySlug', None)
        self.md5 = kwargs.pop('md5', None)
        self.rating = kwargs.pop('rating', None)
        self.avg_color = kwargs.pop('avgColor', None)
        self.user_display_name = kwargs.pop('userDisplayName', None)
        self.user_profile_image_url = kwargs.pop('userProfileImageUrl', None)

    @staticmethod
    def from_dict(http, source):
        return Gfy(http, **source)

    @staticmethod
    def from_dict_list(http, source):
        return [Gfy.from_dict(http, gfy) for gfy in source]

    def set_title(self, new_title):
        payload = {
            'value': new_title
        }

        return self._http.request(Route('PUT', '/me/gfycats/{id}/title', id=self['gfyId']), data=json.dumps(payload))

    def delete_title(self):
        return self._http.request(Route('DELETE', '/me/gfycats/{id}/title', id=self['gfyId']))

    def delete(self):
        return self._http.request(Route('DELETE', '/me/gfycats/{id}', id=self['gfyId']))



from dataclasses import dataclass
from datetime import datetime
from typing import List


@dataclass
class User(dict):
    views: int
    verified: bool
    iframe_profile_image_visible: bool
    url: str
    userid: str
    username: str
    following: int
    followers: int
    create_date: datetime
    description: str
    name: str
    published_gfycats: int
    profile_image_url: str
    email: str
    canonical_username: str
    email_verified: bool
    total_gfycats: int
    total_bookmarks: int
    total_albums: int
    published_albums: int
    subscription: str
    viewing_preference: str
    domain_whitelist: List
    geo_whitelist: List

    def __init__(self, http, **kwargs):
        super().__init__(kwargs)
        self._http = http
        self._source = kwargs

        # explicit cast to int required because the API sometimes returns a str
        self.following = int(kwargs.pop('following')) if 'following' in kwargs else None
        self.followers = int(kwargs.pop('followers')) if 'followers' in kwargs else None
        self.views = int(kwargs.pop('views')) if 'views' in kwargs else None
        self.create_date = datetime.fromtimestamp(int(kwargs.pop('createDate'))) if 'createDate' in kwargs else None
        self.published_gfycats = int(kwargs.pop('publishedGfycats')) if 'publishedGfycats' in kwargs else None
        self.total_gfycats = int(kwargs.pop('totalGfycats')) if 'totalGfycats' in kwargs else None
        self.total_bookmarks = int(kwargs.pop('totalBookmarks')) if 'totalBookmarks' in kwargs else None
        self.total_albums = int(kwargs.pop('totalAlbums')) if 'totalAlbums' in kwargs else None
        self.published_albums = int(kwargs.pop('publishedAlbums')) if 'publishedAlbums' in kwargs else None

        self.subscription = kwargs.pop('subscription', None)
        self.verified = kwargs.pop('verified', None)
        self.iframe_profile_image_visible = kwargs.pop('iframeProfileImageVisible', None)
        self.url = kwargs.pop('url', None)
        self.userid = kwargs.pop('userid', None)
        self.username = kwargs.pop('username', None)
        self.description = kwargs.pop('description', None)
        self.name = kwargs.pop('name', None)
        self.profile_image_url = kwargs.pop('profileImageUrl', None)
        self.email = kwargs.pop('email', None)
        self.canonical_username = kwargs.pop('canonicalUsername', None)
        self.email_verified = kwargs.pop('emailVerified', None)
        self.viewing_preference = kwargs.pop('viewingPreference', None)
        self.domain_whitelist = kwargs.pop('domainWhitelist', None)
        self.geo_whitelist = kwargs.pop('geoWhitelist', None)

    @staticmethod
    def from_dict(http, source):
        return User(http, **source)

    @staticmethod
    def from_dict_list(http, source):
        return [User.from_dict(http, user) for user in source]



from setuptools import setup, find_packages

setup(
    name='gfypy',
    version='1.2.1',
    description='Python wrapper for the Gfycat API',
    long_description='Provides an easy to use interface to the API at '
                     'https://developers.gfycat.com/api/.',
    url='https://github.com/noahkw/gfypy',
    author='Noah K W',
    author_email='noah@dreckbu.de',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    keywords=['gfycat api wrapper'],
    packages=find_packages(),
    install_requires=['requests', 'tqdm'],
    extras_require={
        'async': ['aiohttp']
    },
    scripts=['bin/gfy-uploader']
)
